@@ -18,7 +18,9 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
  ***************************************************************************/
 
- /// NEW:
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <tqwidgetstack.h>
 #include <tqregexp.h>
