@@ -54,7 +54,7 @@ class Tag;
 class State;
 class Note;
 
-class BNPView : public TQSplitter, virtual public BasketDcopInterface
+class KDE_EXPORT BNPView : public TQSplitter, virtual public BasketDcopInterface
 {
 	Q_OBJECT
   
