@@ -20,10 +20,6 @@
 #ifndef PASSWORD_H
 #define PASSWORD_H
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #ifdef Q_MOC_RUN
 #define HAVE_LIBGPGME
 #endif
